@@ -1,5 +1,5 @@
 package App::Munner;
-$App::Munner::VERSION = '0.3.0';
+$App::Munner::VERSION = '0.1';
 =head1 NAME
 
 Munner - Multi-Apps Runner
@@ -36,9 +36,7 @@ in one call. It is a very handy tools to start multiple applications.
 
 =head2 System perl
 
-after install, just call
-
- munner <options>
+ after install, just call munner <options>
 
 =head2 Perlbrew
 
@@ -67,7 +65,6 @@ To run munner, you will need a YAML format of config file.
 The config file name is munner.yml
 
 It looks like this:
-
  ---------------------------
  base_dir: "... base directory to find the app ..."
  apps:
@@ -114,23 +111,6 @@ show this perldoc
 
  perldoc App::Munner
 
-=head1 AUTHOR
-
-Michael Vu <micvu@cpan.org>
-
-=head1 SUPPORT
-
-Please submit bugs to the Bitbucket Issue Tracker: L<http://goo.gl/gHJQii>
-or via email <micvu@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2014 by Michael Vu.
-
-This is free software, licensed under:
-
-The Artistic License 2.0 (GPL Compatible)
-
 =cut
 
 1;
